-- Table: task_type

-- DROP TABLE task_type;

CREATE TABLE task_type
(
  task_type_id bigint NOT NULL,
  class_name character varying(255),
  "name" character varying(255),
  parameters character varying(255),
  parent_class_name character varying(255),
  max_task_concurrent integer,
  CONSTRAINT task_type_pkey PRIMARY KEY (task_type_id)
)
WITHOUT OIDS;
ALTER TABLE task_type OWNER TO spectre_admin;

-- Table: task

-- DROP TABLE task;

CREATE TABLE task
(
  task_id bigint NOT NULL,
  created_by character varying(255),
  creation_time timestamp without time zone,
  description character varying(2000),
  last_run timestamp without time zone,
  "name" character varying(255),
  next_run timestamp without time zone,
  parameters character varying(255),
  schedule character varying(255),
  update_time timestamp without time zone,
  updated_by character varying(255),
  task_type_id bigint,
  disabled boolean,
  cancelled_status boolean,
  collection_size bigint,
  CONSTRAINT task_pkey PRIMARY KEY (task_id),
  CONSTRAINT fk_task_type FOREIGN KEY (task_type_id)
      REFERENCES task_type (task_type_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE task OWNER TO spectre_admin;


-- Table: console

-- DROP TABLE console;

CREATE TABLE console
(
  console_id bigint NOT NULL,
  network_address character varying(255),
  CONSTRAINT console_pkey PRIMARY KEY (console_id)
)
WITHOUT OIDS;
ALTER TABLE console OWNER TO spectre_admin;

-- Table: console_entity

-- DROP TABLE console_entity;

CREATE TABLE console_entity
(
  console_entity_id bigint NOT NULL,
  entity_id bigint,
  "name" character varying(255),
  "type" character varying(255),
  console_id bigint,
  CONSTRAINT console_entity_pkey PRIMARY KEY (console_entity_id),
  CONSTRAINT fk_console FOREIGN KEY (console_id)
      REFERENCES console (console_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE console_entity OWNER TO spectre_admin;


-- Table: task_console_map

-- DROP TABLE task_console_map;

CREATE TABLE task_console_map
(
  task_id bigint NOT NULL,
  console_entity_id bigint NOT NULL,
  CONSTRAINT fk_console_map_task FOREIGN KEY (task_id)
      REFERENCES task (task_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_console_entity FOREIGN KEY (console_entity_id)
      REFERENCES console_entity (console_entity_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE task_console_map OWNER TO spectre_admin;

-- Table: device

-- DROP TABLE device;

CREATE TABLE device
(
  device_id bigint NOT NULL,
  host_ip character varying(255),
  host_name character varying(255),
  idrac_ip character varying(255),
  entity_id bigint,
  CONSTRAINT device_pkey PRIMARY KEY (device_id)
)
WITHOUT OIDS;
ALTER TABLE device OWNER TO spectre_admin;

-- Table: task_execution_history

-- DROP TABLE task_execution_history;

CREATE TABLE task_execution_history
(
  task_execution_history_id bigint NOT NULL,
  end_time timestamp without time zone,
  executed_by character varying(255),
  last_update_time timestamp without time zone,
  message character varying(2000),
  progress character varying(255),
  start_time timestamp without time zone,
  status character varying(255),
  task_id bigint,
  CONSTRAINT task_execution_history_pkey PRIMARY KEY (task_execution_history_id),
  CONSTRAINT fk_task FOREIGN KEY (task_id)
      REFERENCES task (task_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE task_execution_history OWNER TO spectre_admin;

-- Table: task_execution_detail_history

-- DROP TABLE task_execution_detail_history;

CREATE TABLE task_execution_detail_history
(
  task_execution_detail_history_id bigint NOT NULL,
  end_time timestamp without time zone,
  execution_detail character varying(2000),
  execution_summary character varying(255),
  progress character varying(255),
  start_time timestamp without time zone,
  status character varying(255),
  device_id bigint,
  task_execution_history_id bigint,
  lc_error_code character varying(10),
  lc_error_string character varying(2000),
  CONSTRAINT task_execution_detail_history_pkey PRIMARY KEY (task_execution_detail_history_id),
  CONSTRAINT fk_device FOREIGN KEY (device_id)
      REFERENCES device (device_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_task_execution_history FOREIGN KEY (task_execution_history_id)
      REFERENCES task_execution_history (task_execution_history_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE CASCADE
)
WITHOUT OIDS;
ALTER TABLE task_execution_detail_history OWNER TO spectre_admin;

CREATE TABLE task_svctag_map
(
  map_id bigint,
  task_id bigint,
  service_tag character varying(7),
  ip_address character varying(128),
  last_update_time timestamp without time zone,
  task_status character varying(255),
  CONSTRAINT map_id_pkey PRIMARY KEY (map_id),
  CONSTRAINT "task_id_foreignKey" FOREIGN KEY (task_id)
      REFERENCES task (task_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE task_svctag_map OWNER TO spectre_admin;

CREATE TABLE task_hostlist
(
  task_hostlist_id bigint NOT NULL,
  task_id bigint,
  host_name character varying(255),
  CONSTRAINT task_hostlist_pkey PRIMARY KEY (task_hostlist_id),
  CONSTRAINT fk_task FOREIGN KEY (task_id)
      REFERENCES task (task_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE task_hostlist OWNER TO spectre_admin;