CREATE TABLE device_type
(
  device_type bigint not NULL,
  description  character varying(256),
  CONSTRAINT device_type_pkey PRIMARY KEY (device_type)
)
WITHOUT OIDS;
ALTER TABLE device_type OWNER TO spectre_admin;

CREATE SEQUENCE seq_device_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_device_type OWNER TO spectre_admin;

CREATE TABLE power_state
(
  power_state bigint not NULL,
  description  character varying(256),
  CONSTRAINT power_state_pkey PRIMARY KEY (power_state)
)
WITHOUT OIDS;
ALTER TABLE power_state OWNER TO spectre_admin;

CREATE SEQUENCE seq_power_state
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE seq_power_state OWNER TO spectre_admin;


CREATE TABLE device_status
(
  global_status bigint not NULL,
  description  character varying(256),
  CONSTRAINT device_status_pkey PRIMARY KEY (global_status)
)
WITHOUT OIDS;
ALTER TABLE device_status OWNER TO spectre_admin;

CREATE SEQUENCE seq_device_status
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE seq_device_status OWNER TO spectre_admin;


CREATE TABLE management_type
(
  management_type bigint not NULL,
  description  character varying(256),
  CONSTRAINT management_type_pkey PRIMARY KEY (management_type)
)
WITHOUT OIDS;
ALTER TABLE management_type OWNER TO spectre_admin;

CREATE SEQUENCE seq_management_type
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE seq_management_type OWNER TO spectre_admin;


CREATE TABLE location_type
(
  location_type bigint not NULL,
  description  character varying(256),
  CONSTRAINT location_type_pkey PRIMARY KEY (location_type)
)
WITHOUT OIDS;
ALTER TABLE location_type OWNER TO spectre_admin;

CREATE SEQUENCE seq_location_type
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE seq_location_type OWNER TO spectre_admin;


CREATE TABLE software_type
(
  software_type bigint not NULL,
  description  character varying(256),
  CONSTRAINT software_type_pkey PRIMARY KEY (software_type)
)
WITHOUT OIDS;
ALTER TABLE software_type OWNER TO spectre_admin;

CREATE SEQUENCE seq_software_type
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE seq_software_type OWNER TO spectre_admin;


CREATE TABLE infrastructure_device
(
  device_id bigint not NULL,
  global_status  bigint,
  model character varying(256),
  identifier character varying(256),
  device_type bigint not null,
  power_state bigint,
  assetTag character varying(256),
  serviceTag character varying(256),
  last_inventory_time timestamp without time zone,
  CONSTRAINT infrastructure_device_pkey PRIMARY KEY (device_id)
)
WITHOUT OIDS;
ALTER TABLE infrastructure_device OWNER TO spectre_admin;

ALTER TABLE infrastructure_device ADD CONSTRAINT "global_status_FK" FOREIGN KEY (global_status) REFERENCES device_status (global_status) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;
ALTER TABLE infrastructure_device ADD CONSTRAINT "device_type_FK" FOREIGN KEY (device_type) REFERENCES device_type (device_type) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;
ALTER TABLE infrastructure_device ADD CONSTRAINT "power_state_FK" FOREIGN KEY (power_state) REFERENCES power_state (power_state) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;

CREATE SEQUENCE seq_infrastructure_device
  MINVALUE 5000
  MAXVALUE 999999999999
  START WITH 5000
  NO CYCLE;
ALTER TABLE seq_infrastructure_device OWNER TO spectre_admin;

CREATE TABLE device_management
(
  management_id bigint not NULL,
  device_id bigint not NULL,
  ipAddress  character varying(256),
  macAddress character varying(256),
  managementURL character varying(256),
  management_type bigint ,
  
  CONSTRAINT device_management_pkey PRIMARY KEY (management_id)
)
WITHOUT OIDS;
ALTER TABLE device_management OWNER TO spectre_admin;

ALTER TABLE device_management ADD CONSTRAINT "management_type_FK" FOREIGN KEY (management_type)  REFERENCES management_type (management_type) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;
ALTER TABLE device_management ADD CONSTRAINT "infrastructure_device_FK" FOREIGN KEY (device_id)  REFERENCES infrastructure_device (device_id) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;


CREATE SEQUENCE seq_device_management
  MINVALUE 5000
  MAXVALUE 999999999999
  START WITH 5000
  NO CYCLE;
ALTER TABLE seq_device_management OWNER TO spectre_admin;



CREATE TABLE device_software
(
  instanceid character varying(255) NULL,
  device_id bigint not NULL,
  name  character varying(256),
  version  character varying(256),
  installationDate  character varying(256),
  software_type bigint not null,
  manufacturer character varying(256),
  vendorId character varying(256),
  subDeviceId character varying(256),
  subVendorId character varying(256),
  componentId character varying(256),
  
  CONSTRAINT device_software_pkey PRIMARY KEY (instanceId,device_id)
)
WITHOUT OIDS;
ALTER TABLE device_software OWNER TO spectre_admin;

ALTER TABLE device_software ADD CONSTRAINT "software_type_FK" FOREIGN KEY (software_type)  REFERENCES software_type (software_type) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;
ALTER TABLE device_software ADD CONSTRAINT "infrastructure_device_FK" FOREIGN KEY (device_id)  REFERENCES infrastructure_device (device_id) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;


CREATE SEQUENCE seq_device_software
  MINVALUE 5000
  MAXVALUE 999999999999
  START WITH 5000
  NO CYCLE;
ALTER TABLE seq_device_software OWNER TO spectre_admin;


CREATE TABLE infrastructure_group
(
  group_id bigint not NULL,
  group_type character varying(256),
  group_name character varying(256),
  group_description character varying(256),
 
 CONSTRAINT infrastructure_group_pkey PRIMARY KEY (group_id)
)
WITHOUT OIDS;
ALTER TABLE infrastructure_group OWNER TO spectre_admin;

CREATE SEQUENCE seq_infrastructure_group
  MINVALUE 5000
  MAXVALUE 999999999999
  START WITH 5000
  NO CYCLE;
ALTER TABLE seq_infrastructure_group OWNER TO spectre_admin;


CREATE TABLE group_device_association
(
  group_id bigint not NULL,
  device_id bigint not NULL,
  location_name  character varying(256),
  location_type  bigint ,
  location_identifier  character varying(256),
  
  CONSTRAINT group_device_association_pkey PRIMARY KEY (group_id,device_id)
)
WITHOUT OIDS;
ALTER TABLE group_device_association OWNER TO spectre_admin;

ALTER TABLE group_device_association ADD CONSTRAINT "location_type_FK" FOREIGN KEY (location_type)  REFERENCES location_type (location_type) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;
ALTER TABLE group_device_association ADD CONSTRAINT "infrastructure_device_FK" FOREIGN KEY (device_id)  REFERENCES infrastructure_device (device_id) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;
ALTER TABLE group_device_association ADD CONSTRAINT "infrastructure_group_FK" FOREIGN KEY (group_id)  REFERENCES infrastructure_group (group_id) MATCH SIMPLE
  ON UPDATE RESTRICT ON DELETE RESTRICT;


CREATE SEQUENCE seq_group_device_association
  MINVALUE 5000
  MAXVALUE 999999999999
  START WITH 5000
  NO CYCLE;
ALTER TABLE seq_group_device_association OWNER TO spectre_admin;


-- Table: connection_profile
CREATE TABLE tetris_connection_profile_type
(
  profile_type bigint not NULL,
  description  character varying(256),
  CONSTRAINT tetris_connection_profile_type_pkey PRIMARY KEY (profile_type)
)
WITHOUT OIDS;
ALTER TABLE tetris_connection_profile_type OWNER TO spectre_admin;

CREATE SEQUENCE seq_tetris_connection_profile_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_tetris_connection_profile_type OWNER TO spectre_admin;

CREATE TABLE tetris_connection_profile
(
  connection_profile_id bigint NOT NULL,
  created_by character varying(128),
  creation_date timestamp without time zone,
  description character varying(500),
  "name" character varying(250) NOT NULL UNIQUE,
  update_date timestamp without time zone,
  updated_by character varying(255),
  profile_type bigint,
  CONSTRAINT tetris_connection_profile_pkey PRIMARY KEY (connection_profile_id),
   CONSTRAINT tetris_connection_profile_type_fk FOREIGN KEY (profile_type)
      REFERENCES tetris_connection_profile_type (profile_type) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
  
)
WITHOUT OIDS;
ALTER TABLE tetris_connection_profile OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_TETRIS_CONNECTION_PROFILE
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
  ALTER TABLE SEQ_TETRIS_CONNECTION_PROFILE OWNER TO spectre_admin;

-- Table: credentials
CREATE TABLE credential
(
  credential_id bigint NOT NULL,
  "type" integer,
  connection_profile_id bigint,
  parameters_xml character varying(1024000),
  CONSTRAINT credentials_pkey PRIMARY KEY (credential_id),
  CONSTRAINT connection_credentials_fk FOREIGN KEY (connection_profile_id)
      REFERENCES tetris_connection_profile (connection_profile_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE credential OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CREDENTIAL
  MINVALUE 5000
  MAXVALUE 999999999999
  START WITH 5000
  NO CYCLE;
  ALTER TABLE SEQ_CREDENTIAL OWNER TO spectre_admin;

  
CREATE TABLE device_credential_map
(
  device_id bigint NOT NULL,
  credential_id integer NOT NULL,
  operation_type character varying(255),
  CONSTRAINT fk_device_credential_assocication_device FOREIGN KEY (device_id)
      REFERENCES infrastructure_device (device_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_device_credential_assocication_credential FOREIGN KEY (credential_id)
      REFERENCES credential (credential_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
);
ALTER TABLE device_credential_map OWNER TO spectre_admin;

CREATE TABLE io_module_device
(
  io_module_id 		 bigint NOT NULL,
  name 	 			 character varying(255),
  role   	 		 character varying(128),
  fabric   	 		 character varying(128),
  hardware_version	 character varying(128),
  firmware_version   character varying(128),
  present    		 boolean,
  gateway   		 character varying(128),
  subnet_mask  		 character varying(128),
  dhcp_enabled  	 boolean,
  iom_number   		 character varying(128),
  CONSTRAINT io_module_pkey PRIMARY KEY (io_module_id),
  
  CONSTRAINT fk_io_module_device FOREIGN KEY (io_module_id)
  REFERENCES infrastructure_device (device_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);
ALTER TABLE io_module_device OWNER TO spectre_admin;


CREATE TABLE equallogic_group_device
(
  equallogic_group_id bigint NOT NULL,
  name character varying(255),
  CONSTRAINT equallogic_group_pkey PRIMARY KEY (equallogic_group_id),
  CONSTRAINT fk_equallogic_group_device FOREIGN KEY (equallogic_group_id)
      REFERENCES infrastructure_device (device_id) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE
)
WITHOUT OIDS;
ALTER TABLE equallogic_group_device OWNER TO spectre_admin;


CREATE TABLE equallogic_member_device
(
  equallogic_member_id bigint NOT NULL,
  group_id bigint,
  name character varying(255),
  module_id character varying(30),
  fabric character varying(30),
  status_message character varying(255),
  CONSTRAINT equallogic_member_pkey PRIMARY KEY (equallogic_member_id),
  CONSTRAINT fk_equallogic_member_device FOREIGN KEY (equallogic_member_id)
      REFERENCES infrastructure_device (device_id) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT fk_equallogic_member_device_group FOREIGN KEY (group_id)
      REFERENCES infrastructure_group (group_id) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE
)
WITHOUT OIDS;
ALTER TABLE equallogic_member_device OWNER TO spectre_admin;


-- Table: connection_profile_defaults

-- DROP TABLE connection_profile_defaults;

CREATE TABLE connection_profile_defaults
(
  connection_profile_defaults_id bigint NOT NULL,
  "name" character varying(255),
  connection_profile_id bigint,
  "type" character varying(1024000),
  CONSTRAINT credential_profile_defaults_pkey PRIMARY KEY (connection_profile_defaults_id),
  CONSTRAINT connection_profile_FKey FOREIGN KEY (connection_profile_id)
      REFERENCES tetris_connection_profile (connection_profile_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE connection_profile_defaults OWNER TO spectre_admin;

--==========================================================================
--
--  NAME       : SEQ_CP_DEFAULTS
--  Object Type: SEQUENCE
--
--==========================================================================
--DROP SEQUENCE SEQ_CP_DEFAULTS;

CREATE SEQUENCE SEQ_CP_DEFAULTS
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
  ALTER TABLE SEQ_CP_DEFAULTS OWNER TO spectre_admin;  

---------------------------------------------------------------------
--- Tables for discovery
-----------------------------------------------------------------------


create table discovery_configuration
(
	discovery_configuration_id  bigint,        
	ipaddress  character varying(128) ,
	group_id   bigint ,     
	status    character varying(255), 
	CONSTRAINT discovery_configuration_pkey PRIMARY KEY (discovery_configuration_id)
)
WITHOUT OIDS;
ALTER TABLE discovery_configuration OWNER TO spectre_admin;

create table discovery_configuration_group
(
	discovery_configuration_group_id  bigint,        
	server_group_id  integer,
	groupname  character varying(50),
	groupdescription character varying(1000),
	group_id   bigint ,     
	CONSTRAINT discovery_configuration_group_pkey PRIMARY KEY (discovery_configuration_group_id)
)
WITHOUT OIDS;
ALTER TABLE discovery_configuration_group OWNER TO spectre_admin;


create table discovery_configuration_device_association
(
	discovery_group_id   bigint ,
    device_type          bigint ,
    connectionprofileid  bigint, 
	CONSTRAINT discovery_configuration_device_association_pkey PRIMARY KEY (discovery_group_id,device_type,connectionprofileid)
)
WITHOUT OIDS;
ALTER TABLE discovery_configuration_device_association OWNER TO spectre_admin;


CREATE SEQUENCE SEQ_discovery_configuration_group  MINVALUE 5000 MAXVALUE 999999999999 START WITH 5000 NO CYCLE;
ALTER TABLE SEQ_discovery_configuration_group OWNER TO spectre_admin;


CREATE SEQUENCE SEQ_discovery_configuration  MINVALUE 5000 MAXVALUE 999999999999 START WITH 5000 NO CYCLE;
ALTER TABLE SEQ_discovery_configuration OWNER TO spectre_admin;




