#!/bin/bash

#Set the SSL conf file path
filepath="/etc/httpd/conf.d/ssl.conf"
path_ssl_temp="/etc/httpd/conf.d/ssl.conf.tmp"

#Set welcome screen conf path
welcomescreen="/etc/httpd/conf.d/welcome.conf"

#set Spectre tomcat server.xml path and temp file path
path_tomcat="/usr/share/tomcatSpectre/conf/server.xml"
path_tomcat_temp="/usr/share/tomcatSpectre/conf/server.xml.tmp"

#set apache conf path and temp file path
path_apache="/etc/httpd/conf/httpd.conf"
apth_apache_temp="/etc/httpd/conf/httpd.conf.tmp"


#Check if the file is present or not?
if [ ! -f $filepath ]; then
	echo "Error: SSL configuration file not found!"
	exit 1
fi


#Setting up SSL ciphers
sed 's/SSLCipherSuite ALL:!ADH:!EXPORT:!SSLv2:RC4+RSA:+HIGH:+MEDIUM:+LOW/SSLCipherSuite ALL:!aNULL:!ADH:!eNULL:!LOW:!EXP:RC4+RSA:+HIGH:+MEDIUM/' $filepath > $path_ssl_temp
mv $path_ssl_temp $filepath
chmod 644 $filepath

#Disable log files
sed 's/^ErrorLog/#ErrorLog/' $filepath > $path_ssl_temp
mv $path_ssl_temp $filepath
chmod 644 $filepath

sed 's/^TransferLog/#TransferLog/' $filepath > $path_ssl_temp
mv $path_ssl_temp $filepath
chmod 644 $filepath

sed 's/^LogLevel/#LogLevel/' $filepath > $path_ssl_temp
mv $path_ssl_temp $filepath
chmod 644 $filepath

sed 's/^CustomLog/#CustomLog/' $filepath > $path_ssl_temp
mv $path_ssl_temp $filepath
chmod 644 $filepath

sed 's/^ErrorLog/#ErrorLog/' $path_apache > $apth_apache_temp
mv $apth_apache_temp $path_apache
chmod 644 $path_apache

sed 's/^CustomLog/#CustomLog/' $path_apache > $apth_apache_temp
mv $apth_apache_temp $path_apache
chmod 644 $path_apache


#Start Conf
echo "**Start: Apache SSL and Tomcat Configuration**"

#Check if the <Virtual Host Tag is Present in the Conf file
#If the Virtual Host Tag is not present, fail and exit.
vhosttag=`grep '<VirtualHost _default_:443>' ${filepath}`
if [ ${#vhosttag} -eq 0 ]; then
 	echo "SSL Configuration Failed: <VirualHost> tag not found in the ssl.conf file ... exiting script."
  	exit 1
fi

#Check if the configuration is already present or not?
sslconfig=`grep '#Begin spectre_mod_ssl' ${filepath}` 

#If already present, then remove config.
if [ ${#sslconfig} -gt 0 ]; then
   perl -i -n -e "print if not /^#Begin spectre_mod_ssl/ ... /^#End spectre_mod_ssl/" ${filepath}
fi

#Check if VirtualHost end tag is present or not?
#If not then fail and exit.
vhosttag=`grep '</VirtualHost>' ${filepath}`
if [ ${#vhosttag} -eq 0 ]; then
 	echo "SSL Configuration Failed: </VirtualHost> tag not found in the ssl.conf file ... exiting script."
  	exit 1
fi

#Remove the </VirtualHost> tag to be added later
perl -i -n -e "print if not /^<\/VirtualHost>/" ${filepath} 

#Begin the configuration region
echo "#Begin spectre_mod_ssl" >> ${filepath}

#Add configuration steps.
echo "#Send everything for context /VCenter/SpectreSecurity/DellAdminPortal to worker named worker1 (ajp13)" >> ${filepath}
echo  "JkMount /VCenter/* worker1" >> ${filepath}
echo  "JkMount /Spectre/* worker1" >> ${filepath}
echo  "JkMount /SpectreSecurity/* worker1" >> ${filepath}
echo  "JkMount /DellAdminPortal/* worker1" >> ${filepath}
echo  "JkMount /SpectreManager/* worker1" >> ${filepath}

#End the configuration region.
echo "#End spectre_mod_ssl" >> ${filepath}

#Add the </VirtualHost> closing tag.
echo "</VirtualHost>" >> ${filepath}

#removing apache start screen
if [ -f $welcomescreen ]; then
	rm -f $welcomescreen
	if [ $? -ne 0 ]; then
		echo "Error removing welcome screen" >&2
	fi
fi

if [ ! -f $path_apache ]; then
	echo "Error! No httpd.conf file found." >&2
	exit 1
fi

echo "TraceEnable off" >> $path_apache

#removing directory indices
sed  's/Options\ Indexes\ FollowSymLinks/Options\ -Indexes\ FollowSymLinks/' $path_apache > $apth_apache_temp ; mv $apth_apache_temp $path_apache

if [ $? -ne 0 ]; then
	echo "Error removing directory indices from httpd.conf" 
	exit 1
fi

if [ ! -f $path_tomcat ]; then
	echo "Error! No server.xml found!"
	exit 1
fi

#disabling tomcat direct connection
sed '/<Connector port="8080"/,/\/>/d' $path_tomcat > $path_tomcat_temp ; mv $path_tomcat_temp $path_tomcat 


#Adding an address directive to/etc/tomcat/server.xml Connector tag

#Check if the address directive is already there
addressdirective=$(grep 'address="127.0.0.1"' $path_tomcat)

#If not present, then add.
if [ ${#addressdirective} -eq 0 ]; then
    sed s/disableUploadTimeout='"true"'/disableUploadTimeout='"true" address="127.0.0.1"'/ $path_tomcat > $path_tomcat_temp;mv $path_tomcat_temp $path_tomcat 
    sed s/port='"8009"'/port='"8009" address="127.0.0.1"'/ $path_tomcat > $path_tomcat_temp;mv $path_tomcat_temp $path_tomcat 
fi

if [ $? -ne 0 ]; then
	echo "Error disabling tomcat direct connection" >&2
	exit 1
fi

# disable default tomcat instance from starting on boot up
chkconfig tomcat off
if [ $? -ne 0 ]; then
	echo "Error configuring tomcat to be disabled on boot up" >&2
	exit 1
fi

#configuring tomcat-DMPVV and apache to run on boot up
chkconfig tomcatSpectre on
if [ $? -ne 0 ]; then
	echo "Error configuring tomcat-DMPVV to run on boot up" >&2
	exit 1
fi

chkconfig httpd on

if [ $? -ne 0 ]; then
	echo "Error configuring apache to run on boot up" >&2
	exit 1
fi

#Adding the AdminPortal Security

#Adding the Default Spectre Admin User
mkdir -p /usr/share/apache/passwd
htpasswd -c -b /usr/share/apache/passwd/passwords.file admin Password123$
echo "spectre-admin: admin" >> /usr/share/apache/passwd/groups.file
chown apache /usr/share/apache
chown apache /usr/share/apache/passwd
chown apache /usr/share/apache/passwd/passwords.file
chown apache /usr/share/apache/passwd/groups.file

#End Adding the Default Spectre Admin User

echo "<Directory /var/www/html/plugin/adminportal>" >> $path_apache
echo "AllowOverride AuthConfig" >> $path_apache
echo "AuthName Spectre" >> $path_apache
echo "AuthType Basic" >> $path_apache
echo "AuthUserFile /usr/share/apache/passwd/passwords.file" >> $path_apache
echo "AuthGroupFile /usr/share/apache/passwd/groups.file" >> $path_apache
echo "require group spectre-admin" >> $path_apache
echo "</Directory>" >> $path_apache

#Alter httpd.conf to allow for redirection and create .htaccess at doc root (/var/www/html)
sed  's/AllowOverride\ None/AllowOverride \ All/' $path_apache > $apth_apache_temp ; mv $apth_apache_temp $path_apache
val=`/usr/share/webapps/spectre/configscripts/get_ip.sh`
/usr/share/webapps/spectre/configscripts/write_htaccess.sh ${val}

#End Adding the AdminPortal Security

#End Configuration.
echo "******Successfully Configured Apache SSL******"
