#!/bin/bash

THIS_DIR=$(cd $(dirname $0); pwd)

echo "********************Configuration Script Started*********************"

chkconfig spectreboot reset


echo 'Repair tomcat5 links'  
# rm -f /var/lib/tomcat5/common/lib/\[jdbc-stdext\].jar
# rm -f /var/lib/tomcat5/common/lib/\[jndi\].jar
# rm -f /var/lib/tomcat5/common/lib/jdbc-stdext.jar
# rm -f /var/lib/tomcat5/common/lib/jndi.jar
# rm -f /var/lib/tomcat5/server/lib/\[jaas\].jar
# rm -f /var/lib/tomcat5/server/lib/jaas.jar
# ln -s /etc/alternatives/java_home/jre/lib/rt.jar /var/lib/tomcat5/common/lib/jdbc-stdext.jar
# ln -s /etc/alternatives/java_home/jre/lib/rt.jar /var/lib/tomcat5/common/lib/jndi.jar
# ln -s /etc/alternatives/java_home/jre/lib/rt.jar /var/lib/tomcat5/server/lib/jaas.jar

echo "Setting up SELinux"
semodule -i $THIS_DIR/local.pp

# Running DB Script
#echo linux | passwd postgres --stdin
su - postgres -c exit
service postgresql start
chkconfig postgresql on
#sh $THIS_DIR/SpectreDBScript.sh
echo "Calling TetrisMainScript.sh"
sh $THIS_DIR/TetrisMainScript.sh

if [ "$?" -ne 0 ]
	then
		echo "Error executing DB Script."
fi

echo "Copying workers.properties into /etc/httpd/conf/"
cp $THIS_DIR/workers.properties /etc/httpd/conf/

echo "Copying spectre.conf into /etc/httpd/conf.d/"
cp $THIS_DIR/spectre.conf /etc/httpd/conf.d/

echo "Copying provision certificates to proper folder"
cp -r $THIS_DIR/certificates /etc/httpd/conf/ssl.crt
cp $THIS_DIR/ssl_provisionl.conf /etc/httpd/conf.d/

echo "Creating folders for customer certificates"
mkdir /usr/share/webapps/spectre/configscripts/customer/
chown tomcat.tomcat /usr/share/webapps/spectre/configscripts/customer/
mkdir /var/www/html/misc/
chown tomcat.tomcat /var/www/html/misc/
touch /tmp/certCheck.txt
chown tomcat.tomcat /tmp/certCheck.txt

#giving tomcat permission to replace license file
chown tomcat.tomcat /usr/share/webapps/spectre/Spectre/WEB-INF/classes/fileResource/LicenseConfig.xml.asc

echo "Establishing local PW file"
cp $THIS_DIR/passwords.spectre /etc/passwords.spectre
chown tomcat /etc/passwords.spectre
chgrp tomcat /etc/passwords.spectre
chmod 0640 /etc/passwords.spectre

echo "Patching SOAPBuilder"
SOAPPYPATH=/usr/lib/python2.4/site-packages/SOAPpy
cp $THIS_DIR/SOAPBuilder.py $SOAPPYPATH/SOAPBuilder.py
rm $SOAPPYPATH/SOAPBuilder.pyc
rm $SOAPPYPATH/SOAPBuilder.pyo

echo "Opening RPC ports needed for NFS"
# modify /etc/sysconfig/nfs to open the rpc ports for nfs
echo "STATD_PORT=4001" >> /etc/sysconfig/nfs
echo "LOCKD_TCPPORT=4002" >> /etc/sysconfig/nfs
echo "LOCKD_UDPPORT=4002" >> /etc/sysconfig/nfs
echo "MOUNTD_PORT=4003" >> /etc/sysconfig/nfs

echo "rquotad 4004/tcp" >> //etc/services
echo "rquotad 4004/udp" >> //etc/services

echo "setting up IPTABLES"
lokkit -q --enabled
lokkit -q -p 111:tcp
lokkit -q -p 111:udp
lokkit -q -p 80:tcp
lokkit -q -p 443:tcp
lokkit -q -p 4433:tcp
lokkit -q -p 68:udp
lokkit -q -p 162:udp
lokkit -q -p 11620:udp
lokkit -q -p 2049:tcp
lokkit -q -p 2049:udp
lokkit -q -p 4001:udp
lokkit -q -p 4001:tcp
lokkit -q -p 4002:udp
lokkit -q -p 4002:tcp
lokkit -q -p 4003:udp
lokkit -q -p 4003:tcp
lokkit -q -p 4004:udp
lokkit -q -p 4004:tcp
chown root /etc/sysconfig/iptables
chgrp root /etc/sysconfig/iptables
#This is for the trap listener redirection, do not run lokkit after this line, it will undo it
cat $THIS_DIR/iptables_addition >> /etc/sysconfig/iptables
service iptables restart

# security hardening - don't allow usage of pdb debugger from system-config-network-tui, which can exploited to get root access
sed -i -e '/pdb/ s/.*/#commented out p d b/' /usr/sbin/system-config-network-tui

echo "Disable ssh"
service sshd stop
chkconfig sshd off

# Runnig SSL Configuration Script.
sh $THIS_DIR/sslconfig.sh

if [ "$?" -ne 0 ]
	then
		echo "Error executing SSL Configuration Script (sslconfig.sh)."
		exit 1
	else
		echo "SSL Configured Successfully."
	
fi

# Running Certificate Import Script.
$THIS_DIR/cert_import_script.sh

service httpd restart
#service tomcat5 restart

sh $THIS_DIR/nfssetup.sh

echo Setup autofs
service autofs start
chkconfig autofs on


echo Setup dell public key
mkdir /usr/share/tomcatSpectre/.gnupg
gpg --homedir /usr/share/tomcatSpectre/.gnupg --import $THIS_DIR/dell_public.key
gpg --homedir /usr/share/tomcatSpectre/.gnupg --import $THIS_DIR/Dell_VC_Plugin_Public.gpg
chown -R tomcat /usr/share/tomcatSpectre/.gnupg
chgrp -R tomcat /usr/share/tomcatSpectre/.gnupg

echo Configure yum
rpm --import $THIS_DIR/Dell_VC_Plugin_Public.gpg
rm $(ls /etc/yum.repos.d/* | grep -v spectre.repo)

echo NTP ownership changes
chown tomcat.tomcat /etc/ntp.conf
chown tomcat.tomcat /etc/ntp/step-tickers

echo Turn on time sync from VMware Tools first.
/usr/sbin/vmware-guestd --cmd "vmx.set_option synctime 0 1"

echo give tomcat permission to keystore
chown tomcat /usr/lib/jvm/java/jre/lib/security/cacerts

echo create keystore for wsman certs
cp -f /usr/lib/jvm/java/jre/lib/security/cacerts /usr/lib/jvm/java/jre/lib/security/wsmancerts
chown tomcat /usr/lib/jvm/java/jre/lib/security/wsmancerts

echo Installing and Configuring VMwareTools
#vmware-config-tools.pl --default
/usr/share/webapps/spectre/vmwaretools/updateVMwareTools.sh firstRun >> /tmp/VMwareToolsLog

echo Disabling VMwareTools Balloon Driver
locations=/etc/vmware-tools/locations
locations_tmp=/etc/vmware-tools/locations_tmp
modprobe -r vmmemctl
sed "s-answer VMMEMCTL_CONFED yes-answer VMMEMCTL_CONFED no-" $locations > $locations_tmp ; mv $locations_tmp $locations

echo Disabling martian logging
sysctl_conf=/etc/sysctl.conf
sysctl_conf_temp=/tmp/sysctl.conf
sed "s-net.ipv4.conf.all.log_martians = 1-net.ipv4.conf.all.log_martians = 0-" $sysctl_conf > $sysctl_conf_temp ; mv $sysctl_conf_temp $sysctl_conf
sysctl net.ipv4.conf.all.log_martians=0

echo Blacklisting acpiphp
tmp_file=/tmp/modprobe.conf.tmp
sed 's_install pciehp /sbin/modprobe -q --ignore-install acpiphp; /bin/true_#install pciehp /sbin/modprobe -q --ignore-install acpiphp; /bin/true_' /etc/modprobe.conf > $tmp_file
mv $tmp_file /etc/modprobe.conf
echo "blacklist acpiphp" >> /etc/modprobe.d/blacklist
echo "blacklist acpiphp_ibm" >> /etc/modprobe.d/blacklist

#for db backup/restore
echo "%tomcat ALL=NOPASSWD:/sbin/reboot,/sbin/service,/sbin/chkconfig,/usr/sbin/vmware-guestd,/usr/bin/importCustomerCert.sh,/usr/share/webapps/spectre/configscripts/cert_import_script.sh,/usr/bin/yum,/usr/sbin/rpmupdate.sh, /usr/sbin/spectre_debug_mode.sh,/usr/bin/vmware-toolbox-cmd" >> /etc/sudoers
sed 's/Defaults    requiretty/#Defaults    requiretty/' /etc/sudoers > /tmp/sudoers.bk
mv /tmp/sudoers.bk /etc/sudoers
chmod 0440 /etc/sudoers

echo Setting up admin user
useradd admin -s /usr/bin/sudomenu.sh
passwd admin --delete
echo "%admin ALL=NOPASSWD:/usr/bin/python,/usr/bin/spectre_menu.py" >> /etc/sudoers
echo "/usr/bin/sudomenu.sh" >> /etc/shells
rm -f /root/.pwset

echo Setting up readonly user
useradd readonly
echo "%readonly ALL=NOPASSWD:/bin/mount" >> /etc/sudoers

echo "OpenManage Integration Virtual Appliance" > /etc/issue
echo "Log in as admin to continue" >> /etc/issue
echo  >> /etc/issue
sed 's_console__' /etc/securetty > /tmp/securetty ; mv /tmp/securetty /etc/securetty
sed 's_tty1__' /etc/securetty > /tmp/securetty ; mv /tmp/securetty /etc/securetty
sed 's_tty2__' /etc/securetty > /tmp/securetty ; mv /tmp/securetty /etc/securetty

echo "echo NOT SUPPORTED" > /root/.bash_profile
echo "export LANG=en_US.UTF-8" >> /root/.bash_profile
echo "export LANG=en_US.UTF-8" >> /home/admin/.bash_profile

echo Setup CA
mv $THIS_DIR/CA /root/
chmod -R go-rwx /root/CA

userdel -r abuild

echo Setup log rotation
mv /etc/cron.daily/logrotate /etc/cron.hourly/
cp $THIS_DIR/logrotate.d/httpd /etc/logrotate.d/
cp $THIS_DIR/logrotate.d/tomcatSpectre /etc/logrotate.d/

#workaround for system time in the future.
echo "********************Touch network files***********************"
touch /etc/sysconfig/network-scripts/ifcfg-eth0
touch /etc/sysconfig/network
touch /etc/resolv.conf

#directory for spectre log zip
echo "********************Setup directory for SpectreLog***********************"
mkdir /var/www/html/SpectreLog/
chown tomcat.tomcat /var/www/html/SpectreLog/

#copy C lib 
#echo "********************copy C lib***********************"
#echo "cp -p /usr/share/webapps/spectre/configscripts/nativelib/libnativecommands.so /usr/lib/libnativecommands.so"
#cp -p /usr/share/webapps/spectre/configscripts/nativelib/libnativecommands.so /usr/lib/libnativecommands.so 
#chmod 755 /usr/lib/libnativecommands.so

#permissions for spectre.repo file
chown tomcat /etc/yum.repos.d/spectre.repo
chgrp tomcat /etc/yum.repos.d/spectre.repo


echo "********************Configuration Script Ended***********************"
		
